#
# spec file for package razercfg
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           razercfg
Version:        0.43
Release:        1.6
Summary:        A Razer device configuration tool
# Icons are http://creativecommons.org/licenses/by/4.0/
License:        GPL-2.0-or-later AND CC-BY-SA-4.0
Group:          Hardware/Other
URL:            https://bues.ch/cms/hacking/razercfg.html
Source0:        https://bues.ch/razercfg/%{name}-%{version}.tar.xz
Source1:        https://bues.ch/razercfg/%{name}-%{version}.tar.xz.asc
Source99:       %{name}.keyring
# PATCH-FIX-OPENSUSE razercfg-fix-install-in-libdir -- Install libraries in matching directories (e.g. lib64 for 64bit).
# Reported upstream 21. July 2015
Patch0:         razercfg-fix-install-in-libdir.patch
Patch1:	harden_razerd.service.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  libusb-1_0-devel
BuildRequires:  python3-base
BuildRequires:  python3-setuptools
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(udev)
Requires:       python3-qt5
%{?systemd_ordering}

%description
Razercfg is the next generation Razer device configuration
tool bringing the Razer gaming experience to the free Open Source world.
Including commandline tool (razercfg) and QT GUI qrazercfg.

%prep
%autosetup -p1

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install
rm %{buildroot}%{_libdir}/librazer.so
# Fix udev rule location
rm -r %{buildroot}/etc/udev
install -D -m 444 build/udev.rules %{buildroot}%{_udevrulesdir}/80-razer.rules
# backwards compatibility with rcNAME
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcrazerd
# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
help2man -N ./ui/razercfg > %{buildroot}%{_mandir}/man1/razercfg.1
help2man -N -n "Use specific profiles per game" ./ui/razer-gamewrapper > %{buildroot}%{_mandir}/man1/razer-gamewrapper.1
LD_LIBRARY_PATH=./build/librazer/ help2man -N ./build/razerd/razerd > %{buildroot}%{_mandir}/man1/razerd.1
#Desktop file
%suse_update_desktop_file -r %{name} Settings System HardwareSettings Qt

%pre
%service_add_pre razerd.service

%post
%service_add_post razerd.service
%tmpfiles_create %_tmpfilesdir/razerd.conf
%icon_theme_cache_post
udevadm control --reload-rules 2>&1 > /dev/null || :
/sbin/ldconfig

%preun
%service_del_preun razerd.service

%postun
%service_del_postun razerd.service
%icon_theme_cache_postun
udevadm control --reload-rules 2>&1 > /dev/null || :
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc HACKING.md README.md COPYING ui/icons/LICENSE
%{python3_sitelib}/*
%{_sbindir}/rcrazerd
%{_bindir}/razerd
%{_bindir}/razercfg
%{_bindir}/qrazercfg
%{_bindir}/razer-gamewrapper
%{_bindir}/qrazercfg-applet
%{_libdir}/librazer.so.1
%{_unitdir}/razerd.service
%{_tmpfilesdir}/razerd.conf
%{_udevrulesdir}/80-razer.rules
%ghost %{_rundir}/razerd
%{_datadir}/icons/hicolor/scalable/apps/razercfg*.svg
%{_datadir}/applications/razercfg.desktop
%{_mandir}/man1/razer*
%dir %{_sysconfdir}/pm
%dir %{_sysconfdir}/pm/sleep.d
%{_sysconfdir}/pm/sleep.d/50-razer

%changelog
* Thu Oct 24 2024 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.43
- Remove razercfg-rpmlintrc as it is no longer required.
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Nov 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_razerd.service.patch
* Fri Apr 16 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.42
  * Avoid fast infinite loop, if select failed.
  * Rate limit main loop, if any socket operation failed
  * Close client fd on disconnect
  * udev: Only rescan if the removed device is from Razer
* Tue Feb  4 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Removed upstream fixed 59a530d9456351b244ba19b24b2c4bfeaa4207ad.patch
- Update to 0.41
  * Added support for "Razer Deathadder 1800 edition/Korea PCBang"
  * Deactivate Lachesis 5600 support (issues)
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
- BuildRequire python3-base instead of the full python3 package.
* Fri Mar 15 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.40
  * Increase supported resolution of Mouse: MambaTE to 16000dpi
  * QT5 (python-qt5 no PySide anymore)
- Added 59a530d9456351b244ba19b24b2c4bfeaa4207ad.patch from upstream
* Tue Jun 20 2017 rpm@fthiessen.de
- Update to version 0.39
  * Basic support for Diamondback Chroma
  * New maximal DPI: 16'000
  * Some bugfixes for systemd support
* Thu Nov 10 2016 rpm@fthiessen.de
- Added GPG signature / keyring
- Update to version 0.38
  * CMake fixes
  * Fix unaligned access of 16 bit values
  * Added icon to launcher
* Tue Aug 30 2016 aloisio@gmx.com
- Update to version 0.37
* Sat Jul 30 2016 rpm@fthiessen.de
- Update to new upstream release 0.35
- Replaced .desktop and icon with bundled ones
* Thu Jan  7 2016 rpm@fthiessen.de
- Update to new release 0.33:
  * Support new Naga mice
  * Some code improvments
* Mon Nov  2 2015 rpm@fthiessen.de
- Added help2man for creating man pages
* Sun Jul 19 2015 rpm@fthiessen.de
- First version
  * Added patch: razercfg-fix-install-in-libdir.patch
    To install libraries in matching directories
    e.g. 'lib64', report it upstream.
  * Created desktop file
  * razercfg does not provide image,
    so took a public domain one from:
    https://openclipart.org/detail/96913/mouse
  * Requires python3-pyside for qrazercfg gui
